SPY×FAMILY Season 3 - Japanese subtitles - AJATT
Author: Tatsumoto Ren
Description: Japanese subtitles for Japanese anime, dramas, TV shows, and movies
Keywords: japanese, subtitles, anime, TV, dramas, AJATT

# SPY×FAMILY Season 3

Subtitle format: All SRT ASS
wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/SPY%C3%97FAMILY%20Season%203/%5BNanakoRaws%5D%20Spy%20x%20Family%20S3%20-%2001%20%28BS-TX%204K%203840x2160%20x265%20AAC%29.srt'

# | Name | Size | Last modified
--- | --- | --- | ---
1 | [NanakoRaws] Spy x Family S3 - 01 (BS-TX 4K 3840x2160 x265 AAC).srt | 5.00 B | 15 Dec 2025 07:13:38

wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/SPY%C3%97FAMILY%20Season%203/extra/%5BNanakoRaws%5D%20Spy%20x%20Family%20S3%20-%2001%20%28BS-TX%204K%203840x2160%20x265%20AAC%29%281%29.ass' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/SPY%C3%97FAMILY%20Season%203/%5BNanakoRaws%5D%20Spy%20x%20Family%20S3%20-%2001%20%28BS-TX%204K%203840x2160%20x265%20AAC%29.ass' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/SPY%C3%97FAMILY%20Season%203/%5BNanakoRaws%5D%20Spy%20x%20Family%20S3%20-%2001%20%28TX%201920x1080%20x265%20AAC%29.ass'

# | Name | Size | Last modified
--- | --- | --- | ---
1 | extra/[NanakoRaws] Spy x Family S3 - 01 (BS-TX 4K 3840x2160 x265 AAC)(1).ass | 5.00 B | 16 Dec 2025 00:48:26
2 | [NanakoRaws] Spy x Family S3 - 01 (BS-TX 4K 3840x2160 x265 AAC).ass | 5.00 B | 15 Dec 2025 07:13:34
3 | [NanakoRaws] Spy x Family S3 - 01 (TX 1920x1080 x265 AAC).ass | 5.00 B | 15 Dec 2025 07:13:41

wget

    wget --no-glob --no-clobber --content-disposition --trust-server-names --iri 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/SPY%C3%97FAMILY%20Season%203/extra/%5BNanakoRaws%5D%20Spy%20x%20Family%20S3%20-%2001%20%28BS-TX%204K%203840x2160%20x265%20AAC%29%281%29.ass' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/SPY%C3%97FAMILY%20Season%203/%5BNanakoRaws%5D%20Spy%20x%20Family%20S3%20-%2001%20%28BS-TX%204K%203840x2160%20x265%20AAC%29.ass' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/SPY%C3%97FAMILY%20Season%203/%5BNanakoRaws%5D%20Spy%20x%20Family%20S3%20-%2001%20%28BS-TX%204K%203840x2160%20x265%20AAC%29.srt' 'https://raw.githubusercontent.com/Ajatt-Tools/kitsunekko-mirror/refs/heads/main/subtitles/SPY%C3%97FAMILY%20Season%203/%5BNanakoRaws%5D%20Spy%20x%20Family%20S3%20-%2001%20%28TX%201920x1080%20x265%20AAC%29.ass'

# | Name | Size | Last modified
--- | --- | --- | ---
1 | extra/[NanakoRaws] Spy x Family S3 - 01 (BS-TX 4K 3840x2160 x265 AAC)(1).ass | 5.00 B | 16 Dec 2025 00:48:26
2 | [NanakoRaws] Spy x Family S3 - 01 (BS-TX 4K 3840x2160 x265 AAC).ass | 5.00 B | 15 Dec 2025 07:13:34
3 | [NanakoRaws] Spy x Family S3 - 01 (BS-TX 4K 3840x2160 x265 AAC).srt | 5.00 B | 15 Dec 2025 07:13:38
4 | [NanakoRaws] Spy x Family S3 - 01 (TX 1920x1080 x265 AAC).ass | 5.00 B | 15 Dec 2025 07:13:41

Upload new files — Search MAL — Back to Index